developerscripttools.SvnMessageScript
=====================================

.. abjad-lineage:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript

.. autoclass:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.commit_message_path
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.SvnMessageScript.SvnMessageScript.SvnMessageScript.__repr__
   :noindex:
